import { type Wretch } from "wretch";
import { NetlifyClient } from "./netlify_api_client.js";
/**
 * @internal
 */
export declare class AlreadyEnabledError extends Error {
    constructor();
}
/**
 * @internal
 */
export type ExtensionResponse<Config> = {
    id?: string | undefined;
    config: Config;
    has_build_hook_enabled: boolean;
};
/**
 * @internal
 */
export type ConfigurationResponse<Config> = {
    id: string;
    config: Config;
    createdAt: string;
    updatedAt: string;
    teamInstallationId: string;
    siteId?: string | undefined;
    dataLayerId?: string | undefined;
    configurationType: string;
    sourceUrl?: string | undefined;
    name?: string | undefined;
    prefix?: string | undefined;
};
/**
 * @internal
 */
type BuildTokenValidationResponse = {
    token: string;
    site_id: string;
    team_id?: string | undefined;
};
/**
 * @internal
 */
export type NetlifyTokenIssuer = "jigsaw" | "buildbot";
/**
 * @internal
 */
export type ExtensionClientOptions = {
    netlifyApiUrl?: string | undefined;
    jigsawUrl?: string | undefined;
    netlifyTokenIssuer?: NetlifyTokenIssuer | undefined;
};
/**
 * @internal
 */
export type NetlifyExtensionClientConstructorParams = ConstructorParameters<typeof NetlifyExtensionClient>;
/**
 *
 * The `NetlifyExtensionClient` provides different methods to interact with both the Netlify API and
 * the Extension API.
 *
 * When you install the Netlify SDK, you have access to the TypeScript definitions directly in the
 * `@netlify/sdk` package. You can browse through the definition files individually or review the
 * type definition inline, depending on your code editor.
 *
 * @example
 * ```ts
 * import { withNetlifySDKContext } from "@netlify/sdk/ui/functions";
 *
 * export default withNetlifySDKContext((req, context) => {
 *   const { accountId, auth, client } = context;
 *
 *   const accountInfo = await client.getAccount(accountId);
 *
 *   // Using the user’s OAuth connection to make a request to a third-party API
 *   await fetch("https://api.example.com/project", {
 *     headers: {
 *       Authorization: `Bearer ${auth.providerToken}`,
 *     },
 *     method: "POST",
 *     body: JSON.stringify({
 *       name: `project_${accountInfo.name}`,
 *     }),
 *   });
 *
 *   return Response.json({});
 * });
 * ```
 */
export declare class NetlifyExtensionClient<SiteConfiguration, TeamConfiguration, ConnectorConfiguration> extends NetlifyClient {
    netlifyToken?: string | undefined;
    extension: string;
    extensionApi: Wretch;
    teamConfigId?: string | undefined;
    siteConfigId?: string | undefined;
    constructor(netlifyToken: string, extension: string, { jigsawUrl, netlifyApiUrl, netlifyTokenIssuer, }?: ExtensionClientOptions);
    /**
     * Installs this extension for a team.
     */
    installExtensionOnTeam: (teamId: string, hasDataIntegration?: boolean) => Promise<{
        token: string;
    }>;
    /**
     * Uninstalls this extension for a team, which also deletes the configuration.
     */
    uninstallExtensionOnTeam: (teamId: string) => Promise<import("wretch").WretchResponse>;
    /**
     * Upserts a configuration object of type 'team' for the extension installation
     */
    upsertTeamConfiguration: (teamId: string, config: TeamConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Creates a team configuration for an extension installation.
     */
    createTeamConfiguration: (teamId: string, config: TeamConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Updates the extension configuration for a team.
     */
    updateTeamConfiguration: (teamId: string, config: TeamConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Returns the extension configuration for a team for the current extension.
     */
    getTeamConfiguration: (teamId: string) => Promise<ConfigurationResponse<TeamConfiguration> | null>;
    /**
     * Deletes a team configuration for uninstalling the extension.
     */
    deleteTeamConfiguration: (teamId: string) => Promise<import("wretch").WretchResponse>;
    /**
     * Upserts a configuration object of type 'site' for the extension installation
     */
    upsertSiteConfiguration: (teamId: string, siteId: string, config: SiteConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Creates a site configuration for an extension installation.
     */
    createSiteConfiguration: (teamId: string, siteId: string, config: SiteConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Updates the extension configuration for a site.
     */
    updateSiteConfiguration: (teamId: string, siteId: string, config: SiteConfiguration) => Promise<import("wretch").WretchResponse>;
    /**
     * Returns the extension configuration for a site for the current extension.
     */
    getSiteConfiguration: (teamId: string, siteId: string) => Promise<ConfigurationResponse<SiteConfiguration> | null>;
    /**
     * List all site configurations for the specified team.
     */
    listSiteConfigurations: (teamId: string) => Promise<ConfigurationResponse<SiteConfiguration>[]>;
    /**
     * Deletes a site configuration for uninstalling the extension.
     */
    deleteSiteConfiguration: (teamId: string, siteId: string) => Promise<import("wretch").WretchResponse>;
    /**
     * Creates a Connect configuration for an extension installation.
     */
    createConnectConfiguration: ({ teamId, dataLayerId, config, name, prefix, }: {
        teamId: string;
        dataLayerId: string;
        config: ConnectorConfiguration;
        name: string;
        prefix?: string;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Gets a Connect configuration by the specified team ID, data layer ID, and configuration ID.
     */
    getConnectConfiguration: ({ teamId, dataLayerId, configurationId, }: {
        teamId: string;
        dataLayerId: string;
        configurationId: string;
    }) => Promise<ConfigurationResponse<ConnectorConfiguration> | null>;
    /**
     * Updates a Connect configuration, based on the specified configuration ID.
     */
    updateConnectConfiguration: ({ teamId, dataLayerId, configurationId, name, prefix, config, }: {
        teamId: string;
        dataLayerId: string;
        configurationId: string;
        name: string;
        prefix?: string;
        config: ConnectorConfiguration;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Deletes a Connect configuration for uninstalling the extension.
     */
    deleteConnectConfiguration: ({ teamId, dataLayerId, configurationId, }: {
        teamId: string;
        dataLayerId: string;
        configurationId: string;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Creates a visual editor configuration for an extension installation.
     */
    createVisualEditorConfiguration: ({ teamId, siteId, config, name, projectId, prefix, notifyVisualEditor, }: {
        teamId: string;
        siteId: string;
        config: ConnectorConfiguration;
        name: string;
        projectId: string;
        prefix: string;
        notifyVisualEditor?: boolean;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Gets a visual editor configuration by the specified team ID, data layer ID, and configuration
     * ID.
     */
    getVisualEditorConfiguration: ({ teamId, siteId, configurationId, }: {
        teamId: string;
        siteId: string;
        configurationId: string;
    }) => Promise<ConfigurationResponse<ConnectorConfiguration> | null>;
    /**
     * Updates a visual editor configuration, based on the specified configuration ID.
     */
    updateVisualEditorConfiguration: ({ teamId, siteId, configurationId, config, name, projectId, prefix, notifyVisualEditor, }: {
        teamId: string;
        siteId: string;
        configurationId: string;
        config: ConnectorConfiguration;
        name: string;
        projectId: string;
        prefix: string;
        notifyVisualEditor?: boolean;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Deletes a visual editor configuration for uninstalling the extension.
     */
    deleteVisualEditorConfiguration: ({ teamId, siteId, configurationId, projectId, }: {
        teamId: string;
        siteId: string;
        configurationId: string;
        projectId: string;
    }) => Promise<import("wretch").WretchResponse>;
    /**
     * Generates a build token for a site, allowing a build hook to use the Build Context API.
     */
    generateBuildToken: (siteId: string, teamId: string) => Promise<{
        token: string;
    }>;
    /**
     * Validates a build token, returning the siteId and teamId if the token is valid and returning an error if the token is invalid.
     */
    exchangeBuildToken: (siteId: string, teamId: string) => Promise<BuildTokenValidationResponse>;
    /**
     * Sets the build token for a site. Build tokens can be created using the `generateBuildToken`
     * method.
     */
    setBuildToken(accountId: string, siteId: string, token: string): Promise<void>;
    /**
     * Removes the build token for a site.
     */
    removeBuildToken(accountId: string, siteId: string): Promise<void>;
}
export {};
//# sourceMappingURL=extension_api_client.d.ts.map